@@ -3,14 +3,33 @@ package Regexp::Common;
 use 5.00473;
 use strict;
 
-local $^W = 1;
+BEGIN {
+    # This makes sure 'use warnings' doesn't bomb out on 5.005_*;
+    # warnings won't be enabled on those old versions though.
+    # Since all other files use this file, we can use 'use warnings'
+    # elsewhere as well, but *AFTER* 'use Regexp::Common'.
+    if ($] < 5.006) {
+        $INC {"warnings.pm"} = 1;
+        no strict 'refs';
+        *{"warnings::unimport"} = sub {0};
+    }
+}
 
-use vars qw /$VERSION %RE %sub_interface/;
+use warnings;
+use vars qw /$VERSION %RE %sub_interface $AUTOLOAD/;
+
+($VERSION) = q $Revision: 2.122 $ =~ /([\d.]+)/;
 
 
-($VERSION) = q $Revision: 2.119 $ =~ /([\d.]+)/;
+sub _croak {
+    require Carp;
+    goto &Carp::croak;
+}
 
-use Carp;
+sub _carp {
+    require Carp;
+    goto &Carp::carp;
+}
 
 sub new {
     my ($class, @data) = @_;
@@ -35,6 +54,7 @@ my %imports = map {$_ => "Regexp::Common::$_"}
                   zip/;
 
 sub import {
+    shift;  # Shift off the class.
     tie %RE, __PACKAGE__;
     {
         no strict 'refs';
@@ -102,7 +122,7 @@ sub import {
         }
         else {
             next if $exported {$entry};
-            croak "Can't export unknown subroutine &$entry"
+            _croak "Can't export unknown subroutine &$entry"
                 unless $sub_interface {$entry};
             {
                 no strict 'refs';
@@ -113,8 +133,7 @@ sub import {
     }
 }
 
-use vars '$AUTOLOAD';
-sub AUTOLOAD { croak "Can't $AUTOLOAD" }
+sub AUTOLOAD { _croak "Can't $AUTOLOAD" }
 
 sub DESTROY {}
 
@@ -126,10 +145,10 @@ sub _decache {
         my @args = @{tied %{$_[0]}};
         my @nonflags = grep {!/$fpat/} @args;
         my $cache = get_cache(@nonflags);
-        croak "Can't create unknown regex: \$RE{"
+        _croak "Can't create unknown regex: \$RE{"
             . join("}{",@args) . "}"
                 unless exists $cache->{__VAL__};
-        croak "Perl $] does not support the pattern "
+        _croak "Perl $] does not support the pattern "
             . "\$RE{" . join("}{",@args)
             . "}.\nYou need Perl $cache->{__VAL__}{version} or later"
                 unless ($cache->{__VAL__}{version}||0) <= $];
@@ -159,9 +178,9 @@ sub croak_version {
 
 sub pattern {
         my %spec = @_;
-        croak 'pattern() requires argument: name => [ @list ]'
+        _croak 'pattern() requires argument: name => [ @list ]'
                 unless $spec{name} && ref $spec{name} eq 'ARRAY';
-        croak 'pattern() requires argument: create => $sub_ref_or_string'
+        _croak 'pattern() requires argument: create => $sub_ref_or_string'
                 unless $spec{create};
 
         if (ref $spec{create} ne "CODE") {
@@ -186,7 +205,7 @@ sub pattern {
         my $entry = get_cache(@nonflags);
 
         if ($entry->{__VAL__}) {
-                carp "Overriding \$RE{"
+                _carp "Overriding \$RE{"
                    . join("}{",@nonflags)
                    . "}";
         }
@@ -232,9 +251,7 @@ sub subs {
 
 
 package Regexp::Common::Entry;
-use Carp;
-
-local $^W = 1;
+# use Carp;
 
 use overload
     q{""} => sub {
@@ -806,6 +823,15 @@ project, especially: Elijah, Jarkko, Tom, Nat, Ed, and Vivek.
 =head1 HISTORY
 
   $Log: Common.pm,v $
+  Revision 2.122  2008/05/23 21:30:09  abigail
+  Changed email address
+
+  Revision 2.121  2008/05/23 21:28:01  abigail
+  Changed license
+
+  Revision 2.120  2005/03/16 00:24:45  abigail
+  Load Carp only on demand
+
   Revision 2.119  2005/01/01 16:35:14  abigail
   - Updated copyright notice. New release.
 
@@ -988,18 +1014,23 @@ Damian Conway (damian@conway.org)
 
 =head1 MAINTAINANCE
 
-This package is maintained by Abigail S<(I<regexp-common@abigail.nl>)>.
+This package is maintained by Abigail S<(I<regexp-common@abigail.be>)>.
 
 =head1 BUGS AND IRRITATIONS
 
 Bound to be plenty.
 
 For a start, there are many common regexes missing.
-Send them in to I<regexp-common@abigail.nl>.
+Send them in to I<regexp-common@abigail.be>.
 
 =head1 COPYRIGHT
 
-   Copyright (c) 2001 - 2005, Damian Conway and Abigail. All Rights
- Reserved. This module is free software. It may be used, redistributed
-     and/or modified under the terms of the Perl Artistic License
-           (see http://www.perl.com/perl/misc/Artistic.html)
+This software is Copyright (c) 2001 - 2008, Damian Conway and Abigail.
+
+This module is free software, and maybe used under any of the following
+licenses:
+
+ 1) The Perl Artistic License.     See the file COPYRIGHT.AL.
+ 2) The Perl Artistic License 2.0. See the file COPYRIGHT.AL2.
+ 3) The BSD Licence.               See the file COPYRIGHT.BSD.
+ 4) The MIT Licence.               See the file COPYRIGHT.MIT.
