@@ -1,4 +1,4 @@
-# $Id: delimited.pm,v 2.103 2003/07/04 13:34:05 abigail Exp $
+# $Id: delimited.pm,v 2.106 2008/05/23 21:30:09 abigail Exp $
 
 package Regexp::Common::delimited;
 
@@ -8,12 +8,12 @@ local $^W = 1;
 use Regexp::Common qw /pattern clean no_defaults/;
 use vars qw /$VERSION/;
 
-($VERSION) = q $Revision: 2.103 $ =~ /[\d.]+/g;
+($VERSION) = q $Revision: 2.106 $ =~ /[\d.]+/g;
 
 sub gen_delimited {
 
     my ($dels, $escs) = @_;
-    return '(?:\S*)' unless $dels =~ /\S/;
+    # return '(?:\S*)' unless $dels =~ /\S/;
     if (length $escs) {
         $escs .= substr ($escs, -1) x (length ($dels) - length ($escs));
     }
@@ -38,17 +38,14 @@ sub gen_delimited {
     return "(?k:$pat)";
 }
 
-sub local_croak {
-    my $msg = join "", @_;
-    $msg =~ s/\s+$//;
-    die $msg . ' at '
-      . join(" line ", (caller 3)[1,2])
-      . "\n";
+sub _croak {
+    require Carp;
+    goto &Carp::croak;
 }
 
 pattern name   => [qw( delimited -delim= -esc=\\ )],
         create => sub {my $flags = $_[1];
-                       local_croak 'Must specify delimiter in $RE{delimited}'
+                       _croak 'Must specify delimiter in $RE{delimited}'
                              unless length $flags->{-delim};
                        return gen_delimited (@{$flags}{-delim, -esc});
                   },
@@ -145,20 +142,25 @@ Damian Conway (damian@conway.org)
 
 =head1 MAINTAINANCE
 
-This package is maintained by Abigail S<(I<regexp-common@abigail.nl>)>.
+This package is maintained by Abigail S<(I<regexp-common@abigail.be>)>.
 
 =head1 BUGS AND IRRITATIONS
 
 Bound to be plenty.
 
 For a start, there are many common regexes missing.
-Send them in to I<regexp-common@abigail.nl>.
+Send them in to I<regexp-common@abigail.be>.
 
 =head1 COPYRIGHT
 
-     Copyright (c) 2001 - 2003, Damian Conway. All Rights Reserved.
-       This module is free software. It may be used, redistributed
-      and/or modified under the terms of the Perl Artistic License
-            (see http://www.perl.com/perl/misc/Artistic.html)
+This software is Copyright (c) 2001 - 2008, Damian Conway and Abigail.
+
+This module is free software, and maybe used under any of the following
+licenses:
+
+ 1) The Perl Artistic License.     See the file COPYRIGHT.AL.
+ 2) The Perl Artistic License 2.0. See the file COPYRIGHT.AL2.
+ 3) The BSD Licence.               See the file COPYRIGHT.BSD.
+ 4) The MIT Licence.               See the file COPYRIGHT.MIT.
 
 =cut
