@@ -1,16 +1,20 @@
-package Regexp::Common::whitespace; {
+# $Id: whitespace.pm,v 2.105 2008/05/23 21:30:09 abigail Exp $
+
+package Regexp::Common::whitespace;
 
 use strict;
 local $^W = 1;
 
 use Regexp::Common qw /pattern clean no_defaults/;
+use vars qw /$VERSION/;
+
+($VERSION) = q $Revision: 2.105 $ =~ /[\d.]+/g;
 
 pattern name   => [qw (ws crop)],
         create => '(?:^\s+|\s+$)',
         subs   => sub {$_[1] =~ s/^\s+//; $_[1] =~ s/\s+$//;}
         ;
 
-}
 
 1;
 
@@ -59,6 +63,18 @@ This pattern does not capture under C<-keep>.
 =head1 HISTORY
 
  $Log: whitespace.pm,v $
+ Revision 2.105  2008/05/23 21:30:09  abigail
+ Changed email address
+
+ Revision 2.104  2008/05/23 21:28:01  abigail
+ Changed license
+
+ Revision 2.103  2003/07/04 13:34:05  abigail
+ Fixed assignment to
+
+ Revision 2.102  2003/02/11 09:48:54  abigail
+ Added
+
  Revision 2.101  2003/02/01 22:55:31  abigail
  Changed Copyright years
 
@@ -87,20 +103,25 @@ Damian Conway (damian@conway.org)
 
 =head1 MAINTAINANCE
 
-This package is maintained by Abigail S<(I<regexp-common@abigail.nl>)>.
+This package is maintained by Abigail S<(I<regexp-common@abigail.be>)>.
 
 =head1 BUGS AND IRRITATIONS
 
 Bound to be plenty.
 
 For a start, there are many common regexes missing.
-Send them in to I<regexp-common@abigail.nl>.
+Send them in to I<regexp-common@abigail.be>.
 
 =head1 COPYRIGHT
 
-     Copyright (c) 2001 - 2003, Damian Conway. All Rights Reserved.
-       This module is free software. It may be used, redistributed
-      and/or modified under the terms of the Perl Artistic License
-            (see http://www.perl.com/perl/misc/Artistic.html)
+This software is Copyright (c) 2001 - 2008, Damian Conway and Abigail.
+
+This module is free software, and maybe used under any of the following
+licenses:
+
+ 1) The Perl Artistic License.     See the file COPYRIGHT.AL.
+ 2) The Perl Artistic License 2.0. See the file COPYRIGHT.AL2.
+ 3) The BSD Licence.               See the file COPYRIGHT.BSD.
+ 4) The MIT Licence.               See the file COPYRIGHT.MIT.
 
 =cut
